pub struct OptimizeTableInitializers {}Trait Implementations
Sourceimpl Debug for OptimizeTableInitializers
impl Debug for OptimizeTableInitializers
Sourceimpl Default for OptimizeTableInitializers
impl Default for OptimizeTableInitializers
Sourcefn default() -> OptimizeTableInitializers
fn default() -> OptimizeTableInitializers
Returns the “default value” for a type. Read more
Sourceimpl FlawlessRule for OptimizeTableInitializers
impl FlawlessRule for OptimizeTableInitializers
fn flawless_process(&self, block: &mut Block, _: &Context<'_, '_, '_>)
Sourceimpl RuleConfiguration for OptimizeTableInitializers
impl RuleConfiguration for OptimizeTableInitializers
Sourcefn configure(&mut self, _: RuleProperties) -> Result<(), RuleConfigurationError>
fn configure(&mut self, _: RuleProperties) -> Result<(), RuleConfigurationError>
The rule deserializer will construct the default rule and then send the properties through
this method to modify the behavior of the rule.
Sourcefn serialize_to_properties(&self) -> RuleProperties
fn serialize_to_properties(&self) -> RuleProperties
For implementing the serialize trait on the Rule trait, this method should return all
properties that differs from their default value.
Sourcefn has_properties(&self) -> bool
fn has_properties(&self) -> bool
Returns
true if the rule has at least one property.Auto Trait Implementations
impl Freeze for OptimizeTableInitializers
impl RefUnwindSafe for OptimizeTableInitializers
impl Send for OptimizeTableInitializers
impl Sync for OptimizeTableInitializers
impl Unpin for OptimizeTableInitializers
impl UnwindSafe for OptimizeTableInitializers