pub struct RemoveNumberLiterals {}Trait Implementations
Sourceimpl Debug for RemoveNumberLiterals
impl Debug for RemoveNumberLiterals
Sourceimpl Default for RemoveNumberLiterals
impl Default for RemoveNumberLiterals
Sourcefn default() -> RemoveNumberLiterals
fn default() -> RemoveNumberLiterals
Returns the “default value” for a type. Read more
Sourceimpl FlawlessRule for RemoveNumberLiterals
impl FlawlessRule for RemoveNumberLiterals
fn flawless_process(&self, block: &mut Block, _: &Context<'_, '_, '_>)
Sourceimpl RuleConfiguration for RemoveNumberLiterals
impl RuleConfiguration for RemoveNumberLiterals
Sourcefn configure(&mut self, _: RuleProperties) -> Result<(), RuleConfigurationError>
fn configure(&mut self, _: RuleProperties) -> Result<(), RuleConfigurationError>
The rule deserializer will construct the default rule and then send the properties through
this method to modify the behavior of the rule.
Sourcefn serialize_to_properties(&self) -> RuleProperties
fn serialize_to_properties(&self) -> RuleProperties
For implementing the serialize trait on the Rule trait, this method should return all
properties that differs from their default value.
Sourcefn has_properties(&self) -> bool
fn has_properties(&self) -> bool
Returns
true if the rule has at least one property.Auto Trait Implementations
impl Freeze for RemoveNumberLiterals
impl RefUnwindSafe for RemoveNumberLiterals
impl Send for RemoveNumberLiterals
impl Sync for RemoveNumberLiterals
impl Unpin for RemoveNumberLiterals
impl UnwindSafe for RemoveNumberLiterals